From: tip-bot for Thomas Gleixner <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, mingo@redhat.com, hpa@zytor.com,
mingo@kernel.org, peterz@infradead.org, bigeasy@linutronix.de,
tglx@linutronix.de
Subject: [tip:sched/core] sched: Adjust sched_reset_on_fork when nothing else changes
Date: Fri, 21 Feb 2014 13:32:01 -0800 [thread overview]
Message-ID: <tip-a296858625f810c28ceb360d448d4db5758ca48a@git.kernel.org> (raw)
In-Reply-To: <1391803122-4425-5-git-send-email-bigeasy@linutronix.de>
Commit-ID: a296858625f810c28ceb360d448d4db5758ca48a
Gitweb: http://git.kernel.org/tip/a296858625f810c28ceb360d448d4db5758ca48a
Author: Thomas Gleixner <tglx@linutronix.de>
AuthorDate: Fri, 7 Feb 2014 20:58:40 +0100
Committer: Thomas Gleixner <tglx@linutronix.de>
CommitDate: Fri, 21 Feb 2014 21:43:19 +0100
sched: Adjust sched_reset_on_fork when nothing else changes
If the policy and priority remain unchanged a possible modification of
sched_reset_on_fork gets lost in the early exit path.
[bigeasy: rebase ontop of v3.14-rc1]
Cc: Ingo Molnar <mingo@redhat.com>
Cc: stable@vger.kernel.org
Cc: stable@vger.kernel.org
Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
Signed-off-by: Sebastian Andrzej Siewior <bigeasy@linutronix.de>
Signed-off-by: Peter Zijlstra <peterz@infradead.org>
Link: http://lkml.kernel.org/r/1391803122-4425-5-git-send-email-bigeasy@linutronix.de
Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
---
kernel/sched/core.c | 4 +++-
1 file changed, 3 insertions(+), 1 deletion(-)
diff --git a/kernel/sched/core.c b/kernel/sched/core.c
index 241f7465..7527e68 100644
--- a/kernel/sched/core.c
+++ b/kernel/sched/core.c
@@ -3370,7 +3370,8 @@ recheck:
}
/*
* If not changing anything there's no need to proceed further:
*/
if (unlikely(policy == p->policy)) {
if (fair_policy(policy) && attr->sched_nice != task_nice(p))
@@ -3380,6 +3381,7 @@ recheck:
if (dl_policy(policy))
goto change;
+ p->sched_reset_on_fork = reset_on_fork;
task_rq_unlock(rq, p, &flags);
return 0;
}
next prev parent reply other threads:[~2014-02-21 21:32 UTC|newest]
Thread overview: 24+ messages / expand[flat|nested] mbox.gz Atom feed top
2014-02-07 19:58 A pile of sched patches Sebastian Andrzej Siewior
2014-02-07 19:58 ` [PATCH 1/6] sched: Init idle->on_rq in init_idle() Sebastian Andrzej Siewior
2014-02-07 21:09 ` Peter Zijlstra
2014-02-11 9:17 ` [PATCH 1/6 v2] " Sebastian Andrzej Siewior
2014-02-11 9:21 ` Peter Zijlstra
2014-02-11 15:34 ` Thomas Gleixner
2014-02-11 15:51 ` Peter Zijlstra
2014-02-21 21:31 ` [tip:sched/core] " tip-bot for Thomas Gleixner
2014-02-22 18:01 ` tip-bot for Thomas Gleixner
2014-02-07 19:58 ` [PATCH 2/6] sched: Check for idle task in might_sleep() Sebastian Andrzej Siewior
2014-02-21 21:31 ` [tip:sched/core] " tip-bot for Thomas Gleixner
2014-02-22 18:02 ` tip-bot for Thomas Gleixner
2014-02-07 19:58 ` [PATCH 3/6] sched: Better debug output for might sleep Sebastian Andrzej Siewior
2014-02-21 21:31 ` [tip:sched/core] " tip-bot for Thomas Gleixner
2014-02-22 18:02 ` [tip:sched/core] sched: Add better debug output for might_sleep() tip-bot for Thomas Gleixner
2014-02-07 19:58 ` [PATCH 4/6] sched: Adjust sched_reset_on_fork when nothing else changes Sebastian Andrzej Siewior
2014-02-21 21:32 ` tip-bot for Thomas Gleixner [this message]
2014-02-22 18:02 ` [tip:sched/core] sched: Adjust p-> " tip-bot for Thomas Gleixner
2014-02-07 19:58 ` [PATCH 5/6] sched: Queue RT tasks to head when prio drops Sebastian Andrzej Siewior
2014-02-21 21:32 ` [tip:sched/core] " tip-bot for Thomas Gleixner
2014-02-22 18:02 ` tip-bot for Thomas Gleixner
2014-02-07 19:58 ` [PATCH 6/6] sched: Consider pi boosting in setscheduler Sebastian Andrzej Siewior
2014-02-21 21:32 ` [tip:sched/core] " tip-bot for Thomas Gleixner
2014-02-22 18:02 ` [tip:sched/core] sched: Consider pi boosting in setscheduler() tip-bot for Thomas Gleixner
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-a296858625f810c28ceb360d448d4db5758ca48a@git.kernel.org \
--to=tipbot@zytor.com \
--cc=bigeasy@linutronix.de \
--cc=hpa@zytor.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mingo@kernel.org \
--cc=mingo@redhat.com \
--cc=peterz@infradead.org \
--cc=tglx@linutronix.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -3370,7 +3370,8 @@ recheck:
}
/*
- * If not changing anything there's no need to proceed further:
+ * If not changing anything there's no need to proceed further,
+ * but store a possible modification of reset_on_fork.
*/
if (unlikely(policy == p->policy)) {
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox